@@ -277,7 +277,7 @@ update_cursor_values(int x, int y)
          x_offs = pref.use_bitmap ? pref.x_offs : 0,
          y_offs = pref.use_bitmap ? pref.y_offs : 0;
   complex imp, k;
-  char bff[50];
+  char *bff;
   
   gnome_canvas_window_to_world(chart_canvas, x, y, &wx, &wy);
   
@@ -309,22 +309,28 @@ update_cursor_values(int x, int y)
       q = -999.9;
 
   w = lookup_widget(MainWindow, "stat_z_lbl");
-  sprintf(bff, "<span font_desc=\"%s\">%8.2lf %+8.2lfj</span>", 
+  bff = g_strdup_printf("<span font_desc=\"%s\">%8.2lf %+8.2lfj</span>", 
                pref.cursor_font, creal(imp), cimag(imp));
   gtk_label_set_markup(GTK_LABEL(w), bff);
+  g_free(bff);
 
   w = lookup_widget(MainWindow, "stat_zpol_lbl");
-  sprintf(bff, "<span font_desc=\"%s\">%.2lf &lt;%.2lf&#176;</span>", 
+  bff = g_strdup_printf("<span font_desc=\"%s\">%.2lf &lt;%.2lf&#176;</span>",
                pref.cursor_font, cabs(imp), carg(imp)*57.29578);
   gtk_label_set_markup(GTK_LABEL(w), bff);
+  g_free(bff);
   
   w = lookup_widget(MainWindow, "stat_swr_lbl");
-  sprintf(bff, "<span font_desc=\"%s\">%.2lf</span>", pref.cursor_font, swr);
+  bff = g_strdup_printf("<span font_desc=\"%s\">%.2lf</span>",
+		pref.cursor_font, swr);
   gtk_label_set_markup(GTK_LABEL(w), bff);
-
+  g_free(bff);
+  
   w = lookup_widget(MainWindow, "stat_q_lbl");
-  sprintf(bff, "<span font_desc=\"%s\">%.2lf</span>", pref.cursor_font, q);
+  bff = g_strdup_printf("<span font_desc=\"%s\">%.2lf</span>",
+		pref.cursor_font, q);
   gtk_label_set_markup(GTK_LABEL(w), bff);
+  g_free(bff);
 }
 
 //---------------------------------------------------------------------
