@@ -139,7 +139,7 @@ loglist_show(void)
   GtkTreeViewColumn *col;
   GtkWidget *w;
   gboolean is_imp = TRUE;
-  char bff[50], elref[10], row[300];
+  char bff[50], elref[10], row[300], *prow, *trow;
   int ld, el;
   complex c;
 
@@ -147,51 +147,61 @@ loglist_show(void)
   gtk_list_store_clear(loglist.store);
 
   // Element number column header
-  sprintf(row, "<span font_desc=\"%s\">%s</span>",
+  prow = g_strdup_printf("<span font_desc=\"%s\">%s</span>",
 		pref.results_font, _("Elem"));
   col = gtk_tree_view_get_column(logview, LOG_ELEM);
   w = gtk_label_new("");
   gtk_widget_show(w);
-  gtk_label_set_markup(GTK_LABEL(w), row);
+  gtk_label_set_markup(GTK_LABEL(w), prow);
   gtk_tree_view_column_set_widget(col, w);
+  g_free(prow);
 
   // Z/Y mode column header 
-  sprintf(row, "<span font_desc=\"%s\">%s</span>",
+  prow = g_strdup_printf("<span font_desc=\"%s\">%s</span>",
 		pref.results_font, _("Z/Y"));
   col = gtk_tree_view_get_column(logview, LOG_Z_Y);
   w = gtk_label_new("");
   gtk_widget_show(w);   
-  gtk_label_set_markup(GTK_LABEL(w), row);
+  gtk_label_set_markup(GTK_LABEL(w), prow);
   gtk_tree_view_column_set_widget(col, w);
+  g_free(prow);
 
   // Results column header
-  sprintf(row, "<span font_desc=\"%s\">", pref.results_font);
+  prow = g_strdup_printf("<span font_desc=\"%s\">", pref.results_font);
+  trow = prow;
   for (ld = 0; ld < loglist.nr_lds; ld++) {
-    sprintf(bff, "   %9.*f MHz    ", pref.prec_mhz, loglist.freq[ld]);
-    strcat(row, bff);
+    sprintf(bff, "   %11.*f MHz    ", pref.prec_mhz, loglist.freq[ld]);
+    prow = g_strconcat(prow, bff, NULL);
+    g_free(trow);
+    trow = prow;
   }
-  strcat(row, "</span>");
+  prow = g_strconcat(prow, "</span>");
   col = gtk_tree_view_get_column(logview, LOG_RESULT);
   w = gtk_label_new("");
   gtk_widget_show(w);
-  gtk_label_set_markup(GTK_LABEL(w), row);
+  gtk_label_set_markup(GTK_LABEL(w), prow);
   gtk_tree_view_column_set_widget(col, w);
+  g_free(trow); g_free(prow);
 
   // And now the actual results
 
   // First a line with the load impedances
-  row[0] = '\0';
+  prow = strdup("");
+  trow = prow;
   for (ld = 0; ld < loglist.nr_lds; ld++) {
     c = loglist.load[ld];
     sprintf(bff, "%10.3f%+10.3f%s ", creal(c), cimag(c), pref.complex_sfx);
-    strcat(row, bff);
+    prow = g_strconcat(prow, bff, NULL);
+    g_free(trow);
+    trow = prow;
   }
   gtk_list_store_append(loglist.store, &iter);
   gtk_list_store_set(loglist.store, &iter,
 		LOG_ELEM, _("Load"),
 		LOG_Z_Y, _("Z"),
-                LOG_RESULT, row,
+                LOG_RESULT, prow,
                 -1);
+  g_free(prow);
 
   // Then, for each element:
 
@@ -203,21 +213,26 @@ loglist_show(void)
     }
 
     // First show the element value
-    row[0] = '\0';
+    prow = strdup("");
+    trow = prow;
     for (ld = 0; ld < loglist.nr_lds; ld++) {
       c = loglist.elval[el * loglist.nr_lds + ld]; 
       sprintf(bff, "%10.3f%+10.3f%s ", creal(c), cimag(c), pref.complex_sfx);
-      strcat(row, bff);
+      prow = g_strconcat(prow, bff, NULL);
+      g_free(trow);
+      trow = prow;
     }
     sprintf(elref, _("El %d"), el+1);
     gtk_list_store_append(loglist.store, &iter);
     gtk_list_store_set(loglist.store, &iter,
 		LOG_ELEM, elref,
-		LOG_RESULT, loglist.eltype[el] != ELT_ZY ? row : "",
+		LOG_RESULT, loglist.eltype[el] != ELT_ZY ? prow : "",
 		-1);
+    g_free(prow);
 
     // Then show the circuit impedance/admittance
-    row[0] = '\0';
+    prow = strdup("");
+    trow = prow;
     for (ld = 0; ld < loglist.nr_lds; ld++) {
       c = loglist.val[el * loglist.nr_lds + ld];
       if (is_imp || pref.always_imp) {
@@ -230,13 +245,16 @@ loglist_show(void)
 		pref.prec_adm, creal(c), pref.prec_adm, cimag(c),
 		pref.complex_sfx);
       }
-      strcat(row, bff);
+      prow = g_strconcat(prow, bff, NULL);
+      g_free(trow);
+      trow = prow;
     }
     gtk_list_store_append(loglist.store, &iter);
     gtk_list_store_set(loglist.store, &iter,
 		LOG_ELEM, "",
 		LOG_Z_Y, is_imp ? _("Z:") : _("Y:"),
-		LOG_RESULT, row, -1);
+		LOG_RESULT, prow, -1);
+    g_free(prow);
   }
 }
 
